@@ -282,11 +282,8 @@ ebbm_build_cache_update_restriction (EBookBackendMAPI *ebma, TALLOC_CTX *mem_ctx
 
 	set_SPropValue_proptag_date_timeval (&sprop, PR_LAST_MODIFICATION_TIME, &t);
 
-	cast_mapi_SPropValue (
-		#ifdef HAVE_MEMCTX_ON_CAST_MAPI_SPROPVALUE
-		mem_ctx,
-		#endif
-		&(restriction->res.resProperty.lpProp), &sprop);
+	cast_mapi_SPropValue (mem_ctx, &(restriction->res.resProperty.lpProp),
+			      &sprop);
 
 	return restriction;
 }
@@ -440,10 +437,12 @@ ebbm_open (EBookBackendMAPI *ebma, GCancellable *cancellable, gboolean only_if_e
 
 	/* Once aunthentication in address book works this can be removed */
 	if (!e_book_backend_is_online (E_BOOK_BACKEND (ebma))) {
+		e_book_backend_notify_online (E_BOOK_BACKEND (ebma), FALSE);
 		e_book_backend_notify_opened (E_BOOK_BACKEND (ebma), NULL /* Success */);
 		return;
 	}
 
+	e_book_backend_notify_online (E_BOOK_BACKEND (ebma), TRUE);
 	e_book_backend_notify_auth_required (E_BOOK_BACKEND (ebma), TRUE, NULL);
 }
 
