@@ -181,43 +181,43 @@ fetch_read_item_common_data (MailItem *item, uint32_t propTag, gconstpointer pro
 		} break;
 	/* FIXME : Instead of duping. Use talloc_steal to reuse the memory */
 	case PR_SUBJECT:
-		sv (item->header.subject, utf8tolinux (prop_data));
+		sv (item->header.subject, g_strdup (prop_data));
 		break;
 	case PR_SUBJECT_UNICODE :
 		sv (item->header.subject, g_strdup (prop_data));
 		break;
 	case PR_DISPLAY_TO :
-		sv (item->header.to, utf8tolinux (prop_data));
+		sv (item->header.to, g_strdup (prop_data));
 		break;
 	case PR_DISPLAY_TO_UNICODE :
 		sv (item->header.to, g_strdup (prop_data));
 		break;
 	case PR_DISPLAY_CC:
-		sv (item->header.cc, utf8tolinux (prop_data));
+		sv (item->header.cc, g_strdup (prop_data));
 		break;
 	case PR_DISPLAY_CC_UNICODE:
 		sv (item->header.cc, g_strdup (prop_data));
 		break;
 	case PR_DISPLAY_BCC:
-		sv (item->header.bcc, utf8tolinux (prop_data));
+		sv (item->header.bcc, g_strdup (prop_data));
 		break;
 	case PR_DISPLAY_BCC_UNICODE:
 		sv (item->header.bcc, g_strdup (prop_data));
 		break;
 	case PR_SENT_REPRESENTING_NAME:
-		sv (item->header.from, utf8tolinux (prop_data));
+		sv (item->header.from, g_strdup (prop_data));
 		break;
 	case PR_SENT_REPRESENTING_NAME_UNICODE:
 		sv (item->header.from, g_strdup (prop_data));
 		break;
 	case PR_SENT_REPRESENTING_EMAIL_ADDRESS:
-		sv (item->header.from_email, utf8tolinux (prop_data));
+		sv (item->header.from_email, g_strdup (prop_data));
 		break;
 	case PR_SENT_REPRESENTING_EMAIL_ADDRESS_UNICODE:
 		sv (item->header.from_email, g_strdup (prop_data));
 		break;
 	case PR_SENT_REPRESENTING_ADDRTYPE:
-		sv (item->header.from_type, utf8tolinux (prop_data));
+		sv (item->header.from_type, g_strdup (prop_data));
 		break;
 	case PR_SENT_REPRESENTING_ADDRTYPE_UNICODE:
 		sv (item->header.from_type, g_strdup (prop_data));
@@ -235,7 +235,7 @@ fetch_read_item_common_data (MailItem *item, uint32_t propTag, gconstpointer pro
 		item->header.in_reply_to = g_strdup (prop_data);
 		break;
 	case PR_TRANSPORT_MESSAGE_HEADERS:
-		sv (item->header.transport_headers, utf8tolinux (prop_data));
+		sv (item->header.transport_headers, g_strdup (prop_data));
 		break;
 	case PR_TRANSPORT_MESSAGE_HEADERS_UNICODE:
 		sv (item->header.transport_headers, g_strdup (prop_data));
@@ -355,18 +355,15 @@ mapi_mime_set_recipient_list (ExchangeMapiConnection *conn, CamelMimeMessage *ms
 		struct SRow *aRow;
 		ExchangeMAPIRecipient *recip = (ExchangeMAPIRecipient *)(l->data);
 
-		/*Can't continue when there is no email-id*/
-		if (!recip->email_id)
-			continue;
-
 		/* Build a SRow structure */
 		aRow = &recip->out_SRow;
 
 		/*Name is probably available in one of these props.*/
-		name = (const gchar *) exchange_mapi_util_find_row_propval (aRow, PR_DISPLAY_NAME_UNICODE);
-		name = name ? name : (const gchar *) exchange_mapi_util_find_row_propval (aRow, PR_RECIPIENT_DISPLAY_NAME_UNICODE);
+		name = recip->display_name;
+		name = name ? name : exchange_mapi_util_find_row_propval (aRow, PR_DISPLAY_NAME_UNICODE);
+		name = name ? name : exchange_mapi_util_find_row_propval (aRow, PR_RECIPIENT_DISPLAY_NAME_UNICODE);
 		if (!name) {
-			name = (const gchar *) exchange_mapi_util_find_row_propval (aRow, PR_7BIT_DISPLAY_NAME_UNICODE);
+			name = exchange_mapi_util_find_row_propval (aRow, PR_7BIT_DISPLAY_NAME_UNICODE);
 			if (name && !strchr (name, '@')) {
 				gchar *to_free;
 
@@ -377,34 +374,48 @@ mapi_mime_set_recipient_list (ExchangeMapiConnection *conn, CamelMimeMessage *ms
 
 		type = (uint32_t *) exchange_mapi_util_find_row_propval (aRow, PR_RECIPIENT_TYPE);
 
-		if (!display_name && name && recip->email_id && !name_is_email_user (name, recip->email_id))
+		if (!display_name && name && (!recip->email_id || !name_is_email_user (name, recip->email_id)))
 			display_name = g_strdup (name);
 		rcpt_type = (type ? *type : MAPI_TO);
 
+		if (!display_name && (!recip->email_id || !*recip->email_id))
+			break;
+
 		switch (rcpt_type) {
 		case MAPI_TO:
-			camel_internet_address_add (to_addr, display_name, recip->email_id);
+			camel_internet_address_add (to_addr, display_name, recip->email_id ? recip->email_id : "");
 			break;
 		case MAPI_CC:
-			camel_internet_address_add (cc_addr, display_name, recip->email_id);
+			camel_internet_address_add (cc_addr, display_name, recip->email_id ? recip->email_id : "");
 			break;
 		case MAPI_BCC:
-			camel_internet_address_add (bcc_addr, display_name, recip->email_id);
+			camel_internet_address_add (bcc_addr, display_name, recip->email_id ? recip->email_id : "");
 			break;
 		}
 
 		g_free (display_name);
 	}
 
-	/*Add to message*/
-	/*Note : To field is added from PR_TRANSPORT_MESSAGE_HEADERS
-	  But, in sent_items folder we don't get TRANSPORT_MESSAGE_HEADERS */
-	if (!item->header.transport_headers) {
-		camel_mime_message_set_recipients(msg, "To", to_addr);
-		camel_mime_message_set_recipients(msg, "Cc", cc_addr);
-		camel_mime_message_set_recipients(msg, "Bcc", bcc_addr);
+	if (l != NULL) {
+		/* some recipient didn't have set email or
+		   display name, fallback to PR_DISPLAY_TO/_CC/_BCC */
+		camel_address_remove (CAMEL_ADDRESS (to_addr), -1);
+		camel_address_remove (CAMEL_ADDRESS (cc_addr), -1);
+		camel_address_remove (CAMEL_ADDRESS (bcc_addr), -1);
+
+		if (item->header.to && *item->header.to)
+			camel_address_decode (CAMEL_ADDRESS (to_addr), item->header.to);
+		if (item->header.cc && *item->header.cc)
+			camel_address_decode (CAMEL_ADDRESS (cc_addr), item->header.cc);
+		if (item->header.bcc && *item->header.bcc)
+			camel_address_decode (CAMEL_ADDRESS (bcc_addr), item->header.bcc);
 	}
 
+	/*Add to message*/
+	camel_mime_message_set_recipients (msg, "To", to_addr);
+	camel_mime_message_set_recipients (msg, "Cc", cc_addr);
+	camel_mime_message_set_recipients (msg, "Bcc", bcc_addr);
+
 	g_object_unref (to_addr);
 	g_object_unref (cc_addr);
 	g_object_unref (bcc_addr);
@@ -835,7 +846,7 @@ mapi_mime_classify_attachments (ExchangeMapiConnection *conn, mapi_id_t fid, con
 
 			mem = camel_stream_mem_new ();
 			camel_stream_write (mem, (const gchar *) stream->value->data, stream->value->len, NULL, NULL);
-			camel_stream_reset (mem, NULL);
+			g_seekable_seek (G_SEEKABLE (mem), 0, G_SEEK_SET, NULL, NULL);
 
 			parser = camel_mime_parser_new ();
 			camel_mime_parser_scan_from (parser, FALSE);
@@ -911,7 +922,7 @@ mapi_mail_item_to_mime_message (ExchangeMapiConnection *conn, MailItem *item)
 									inline_attachs);
 	} else if (build_related) {
 		multipart_body = mapi_mime_build_multipart_related (item,
-								    item->msg.body_parts->data,
+								    item->msg.body_parts ? item->msg.body_parts->data : NULL,
 								    inline_attachs);
 	} else { /* Simple multipart/mixed */
 		CamelMimePart *part;
